$(document).ready(function() {
    var $verifyButton = $('#verify_token');
    var $tokenInput = $('textarea[name="BAYARCASH_PAT"]');
    var $verificationResult = $('#token_verification_result');
    var $portalWrapper = $('#portal_selection_wrapper');
    var $portalSelect = $('#portal_selection');

    // Auto-resize textarea based on content
    $tokenInput.on('input', function() {
        this.style.height = 'auto';
        this.style.height = (this.scrollHeight) + 'px';
    });

    // Initialize from PHP state
    if (typeof bayarcashInitialState !== 'undefined' && bayarcashInitialState.hasToken) {
        verifyToken(true); // Changed to true to show messages during auto-verify
    }

    // Trigger initial resize
    $tokenInput.trigger('input');

    // Function to verify token
    function verifyToken(showMessages = true) {
        var token = $tokenInput.val().trim();
        if (!token) {
            if (showMessages) {
                showVerificationMessage('error', 'Please enter a Personal Access Token');
            }
            return;
        }

        // Show loading state
        if (showMessages) {
            $verifyButton.prop('disabled', true);
            $verifyButton.html('<i class="icon icon-spinner icon-spin"></i> Verifying...');
        }

        // Make AJAX call to verify token
        $.ajax({
            url: bayarcashAjaxUrl,
            type: 'POST',
            data: {
                ajax: 1,
                action: 'refreshPortals',
                token: bayarcashToken,
                pat: token
            },
            dataType: 'json',
            success: function(response) {
                console.log('API Response:', response);

                if (response.status === 'success' && response.portals && response.portals.length > 0) {
                    if (showMessages) {
                        showVerificationMessage('success', 'Token verified successfully!');
                    }
                    populatePortals(response.portals);
                    $portalWrapper.slideDown();
                } else {
                    if (showMessages) {
                        let errorMessage = response.message || 'Invalid token or no portals found';
                        if (response.debug) {
                            errorMessage += '<br><br>Debug Information:';
                            errorMessage += '<br>API Endpoint: ' + response.debug.endpoint;
                            errorMessage += '<br>HTTP Code: ' + response.debug.httpCode;
                            if (response.debug.curlError) {
                                errorMessage += '<br>Curl Error: ' + response.debug.curlError;
                            }
                        }
                        showVerificationMessage('error', errorMessage);
                    }
                    $portalWrapper.slideUp();
                }
            },
            error: function(jqXHR, textStatus, errorThrown) {
                if (showMessages) {
                    let errorMessage = 'Failed to verify token. ';
                    errorMessage += '<br>Status: ' + textStatus;
                    errorMessage += '<br>Error: ' + errorThrown;
                    showVerificationMessage('error', errorMessage);
                }
            },
            complete: function() {
                // Reset button state
                if (showMessages) {
                    $verifyButton.prop('disabled', false);
                    $verifyButton.html('<i class="icon icon-check"></i> Verify Token');
                }
            }
        });
    }

    // Manual verification when button is clicked
    $verifyButton.on('click', function() {
        verifyToken(true);
    });

    function showVerificationMessage(type, message) {
        $verificationResult
            .removeClass('alert-success alert-danger')
            .addClass(type === 'success' ? 'alert alert-success' : 'alert alert-danger')
            .html(message)
            .slideDown();
    }

    function populatePortals(portals) {
        var currentValue = $portalSelect.val();
        $portalSelect.empty()
            .append($('<option>', {
                value: '',
                text: 'Select a portal'
            }));

        portals.forEach(function(portal) {
            $portalSelect.append($('<option>', {
                value: portal.id,
                text: portal.name,
                selected: portal.id === currentValue || portal.id === bayarcashInitialState.selectedPortal
            }));
        });
    }
});